Pipeline
========

.. image:: https://travis-ci.org/jazzband/django-pipeline.svg?branch=master
    :alt: Build Status
    :target: http://travis-ci.org/jazzband/django-pipeline

.. image:: https://coveralls.io/repos/github/jazzband/django-pipeline/badge.svg?branch=master
    :alt: Code Coverage
    :target: https://coveralls.io/github/jazzband/django-pipeline?branch=master

.. image:: https://jazzband.co/static/img/badge.svg
    :alt: Jazzband
    :target: https://jazzband.co/

.. image:: https://badge.fury.io/py/django-pipeline.svg
    :alt: PYPI
    :target: https://badge.fury.io/py/django-pipeline

.. image:: https://readthedocs.org/projects/django-pipeline/badge/?version=latest
    :alt: Documentation Status
    :target: https://django-pipeline.readthedocs.io/en/latest/?badge=latest


Pipeline is an asset packaging library for Django, providing both CSS and
JavaScript concatenation and compression, built-in JavaScript template support,
and optional data-URI image and font embedding.


Installation
------------

To install it, simply: ::

    pip install django-pipeline


Documentation
-------------

For documentation, usage, and examples, see :
https://django-pipeline.readthedocs.io
